@@ -10,8 +10,8 @@ class Sysam():
         print("nom: ", nom, end = ")\n")        
 
 
-    def close(self):
-        print("Sysam: close()")
+    def fermer(self):
+        print("Sysam: fermer()")
 
     def config_entrees(self, voies, calibres, diff=[]):
         print("Sysam: ", end = "config_entrees(")
